@@ -134,7 +134,10 @@ module Net
         # +true+. If no block is given, then the loop continues until there
         # are no more open channels on this connection.
         def loop( &block )
-          block ||= proc { not @channel_map.empty? }
+          block ||= proc do 
+            channels = @channel_map.reject {|k,v| v.type == 'auth-agent@openssh.com' }
+            not channels.empty?
+          end
           process while block.call
         end
 
@@ -178,6 +181,17 @@ module Net
           self
         end
 
+        # Send a channel request packet to the server.
+        def channel_request( type )
+          writer = @buffers.writer
+          writer.write_byte CHANNEL_REQUEST
+          writer.write_long 0 # channel id
+          writer.write_string type
+          writer.write_byte 0 # want_confirm
+          
+          @session.send_message writer
+        end
+
         # A convenience method for sending messages.
         def send_message( msg )
           @session.send_message msg
