@@ -71,6 +71,7 @@ module Net
         def initialize( host, options={} )
           @saved_message = nil
           @session_id = nil
+          @host = host
 
           yield self
 
@@ -100,6 +101,15 @@ module Net
           kexinit
         end
 
+        # Returns info about the remote peer
+        def peer
+          @peer ||= begin
+            addr = @socket.getpeername
+            ip_address = Socket.getnameinfo(addr, Socket::NI_NUMERICHOST | Socket::NI_NUMERICSERV).first
+            { :ip => ip_address, :port => @port.to_i, :host => @host }
+          end
+        end
+
         # Returns the name of the client's host, as reported by the socket.
         def client_name
           return @hostname if defined? @hostname
